@@ -523,6 +523,9 @@ class recset(Generic[T]):
         # フィールドクラス
         self.__fields = fields(self.__rows, self.__dfrows)
 
+        # セッションチェック
+        self.__checkSession(False, False)
+
         # クエリ実行
         rowIndex = 0
         q = self.__session.query(self.modelType).filter(w).all()
@@ -548,6 +551,9 @@ class recset(Generic[T]):
         row : Any
             行情報
         """
+
+        # セッションチェック
+        self.__checkSession(False, False)
         
         # 主キーを条件として該当レコードが存在するか確認
         w = self.__getPKeyFilter_sa(row)
@@ -636,6 +642,32 @@ class recset(Generic[T]):
         # fields再構築
         self.__fields = fields(self.__rows, self.__dfrows)
         
+    def __checkSession(self, __autoCommit = True, __beginTransaction = False):
+
+        """
+        セッションチェック
+
+        Parameters
+        ----------
+        __autoCommit : bool
+            AutoCommit
+        __beginTransaction : bool
+            Sessionを開いた時にトランザクションを開始するか
+
+        """
+        
+        # sessionがNoneの場合はautocommit=Onで接続を開く
+        if self.__session is None:
+            self.__da.openSession(__autoCommit)
+            self.__session = self.__da.session
+            self.__da.beginTransaction()
+        else:
+            # autocommit=Onの場合はtrunsactionを開始する
+            if self.__da.autoCommit and \
+               self.session.transaction is None and \
+               __beginTransaction:
+                self.__da.beginTransaction()
+            
     def upsert(self):
 
         """
@@ -663,7 +695,10 @@ class recset(Generic[T]):
         """
         
         try:
-        
+            
+            # セッションチェック
+            self.__checkSession(True, True)
+            
             # 新規行はaddする
             newRows = [row for row in self.__rows if row._recset__rowState == self.rowState.added]
             for newRow in newRows:
@@ -677,7 +712,7 @@ class recset(Generic[T]):
                 self.__session.delete(delRow)
 
             # Commit
-            if self.__da.autoCommit:
+            if self.__da.autoCommit and not self.session.transaction is None:
                 self.__session.commit()
 
             # 処理結果セット
